:
###############################################################################
#                                                                             #
#  unmountcmd.sh	sample script for UNMOUNTCMD                          #
#                                                                             #
#     If the UNMOUNTCMD variable is set, this command will be called AFTER    #
#     BRU is done reading/writing a tape.                                     #
#                                                                             #
#     The UNMOUNTCMD will not be called unless the MOUNTCMD was specified.    #
#     It is NOT possible to call the UNMOUNTCMD only.  In most cases, the     #
#     UNMOUNTCMD is not needed, as all the tape handling, jukebox commands,   #
#     etc. can be done by the MOUNTCMD.                                       #
#                                                                             #
#     Please modify this script to suit your own needs.                       #
#                                                                             # 
#                                                                             #
###############################################################################

CMD=$0		# name of this command

DEV=$1		# 1st parameter is device name
VOL=$2		# 2nd parameter is volume number 
MODE=$3		# 3rd parameter is BRU mode letter
IOSIZE=$4	# 4th parameter is Kbytes written/read


case "$MODE" in
     c ) :
	#----------------------------------------------------------
	# Replace the following lines with any commands           |
	# that should be called after BRU is done WRITING a tape  |
	#----------------------------------------------------------

	echo "$CMD: volume $VOL on device $DEV (mode = $MODE)"	
	RTN=$?		# set return code
	;;
    [idtgx] ) :
	#----------------------------------------------------------
	# Replace the following lines with any commands           |
	# that should be called after BRU is done READING a tape  |
	#----------------------------------------------------------

	echo "$CMD: volume $VOL on device $DEV (mode = $MODE)"	
	RTN=$?		# set return code
	;;
esac

exit $RTN	# return 0 if succesful
